pub const OCFL_1_0_SPEC: &str = include_str!("../../resources/main/specs/ocfl_1.0.txt");
pub const EXT_0002_SPEC: &str =
    include_str!("../../resources/main/specs/0002-flat-direct-storage-layout.md");
pub const EXT_0003_SPEC: &str =
    include_str!("../../resources/main/specs/0003-hash-and-id-n-tuple-storage-layout.md");
pub const EXT_0004_SPEC: &str =
    include_str!("../../resources/main/specs/0004-hashed-n-tuple-storage-layout.md");
pub const EXT_0006_SPEC: &str =
    include_str!("../../resources/main/specs/0006-flat-omit-prefix-storage-layout.md");
pub const EXT_0007_SPEC: &str =
    include_str!("../../resources/main/specs/0007-n-tuple-omit-prefix-storage-layout.md");
